@@ -45,18 +45,20 @@
 #'   `beta` or `precision` (and other auxiliary parameters) are returned.
 #'
 #' @return A list of character vectors that represent the name(s) of the
-#'    predictor variables. Depending on the combination of the arguments
-#'    `effects` and `component`, the returned list has following
-#'    elements:
-#'    \itemize{
-#'      \item `conditional`, the "fixed effects" terms from the model
-#'      \item `random`, the "random effects" terms from the model
-#'      \item `zero_inflated`, the "fixed effects" terms from the zero-inflation component of the model
-#'      \item `zero_inflated_random`, the "random effects" terms from the zero-inflation component of the model
-#'      \item `dispersion`, the dispersion terms
-#'      \item `instruments`, for fixed-effects regressions like `ivreg`, `felm` or `plm`, the instrumental variables
-#'      \item `correlation`, for models with correlation-component like `gls`, the variables used to describe the correlation structure
-#'    }
+#' predictor variables. Depending on the combination of the arguments
+#' `effects` and `component`, the returned list has following elements:
+#'
+#' - `conditional`, the "fixed effects" terms from the model
+#' - `random`, the "random effects" terms from the model
+#' - `zero_inflated`, the "fixed effects" terms from the zero-inflation
+#'   component of the model
+#' - `zero_inflated_random`, the "random effects" terms from the zero-inflation
+#'   component of the model
+#' - `dispersion`, the dispersion terms
+#' - `instruments`, for fixed-effects regressions like `ivreg`, `felm` or `plm`,
+#'   the instrumental variables
+#' - `correlation`, for models with correlation-component like `gls`, the
+#'   variables used to describe the correlation structure
 #'
 #' @examples
 #' data(mtcars)
@@ -107,22 +109,21 @@ find_predictors.default <- function(x,
   # manually, so other functions like "get_data()" work as expected...
 
   if (object_has_names(l, "random") && effects == "all") {
-    random_slope <- unname(unlist(find_random_slopes(x)))
-    all_predictors <- unlist(unique(l))
+    random_slope <- unlist(find_random_slopes(x), use.names = FALSE)
+    all_predictors <- unlist(unique(l), use.names = FALSE)
     rs_not_in_pred <- unique(setdiff(random_slope, all_predictors))
     if (length(rs_not_in_pred)) l$random <- c(rs_not_in_pred, l$random)
   }
 
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
 }
 
 
-
 #' @export
 find_predictors.selection <- function(x, flatten = FALSE, verbose = TRUE, ...) {
   elements <- .get_elements("all", "all")
@@ -138,7 +139,7 @@ find_predictors.selection <- function(x, flatten = FALSE, verbose = TRUE, ...) {
   }
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -150,7 +151,7 @@ find_predictors.logitr <- function(x, flatten = FALSE, ...) {
   l <- find_predictors.default(x)
   l[["cluster"]] <- get_call(x)$obsID
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -182,13 +183,13 @@ find_predictors.fixest <- function(x, flatten = FALSE, ...) {
   }
 
   l <- compact_list(list(
-    "conditional" = conditional,
-    "cluster" = cluster,
-    "instruments" = instruments,
-    "endogenous" = endo
+    conditional = conditional,
+    cluster = cluster,
+    instruments = instruments,
+    endogenous = endo
   ))
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -199,14 +200,14 @@ find_predictors.fixest <- function(x, flatten = FALSE, ...) {
 find_predictors.bfsl <- function(x, flatten = FALSE, verbose = TRUE, ...) {
   l <- list(conditional = "x")
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
 }
 
 
-
+#' @rdname find_predictors
 #' @export
 find_predictors.afex_aov <- function(x,
                                      effects = c("fixed", "random", "all"),
@@ -224,7 +225,7 @@ find_predictors.afex_aov <- function(x,
   )[effects]
 
   if (flatten) {
-    unique(unlist(l))
+    unique(unlist(l, use.names = FALSE))
   } else {
     l
   }
@@ -260,7 +261,7 @@ find_predictors.afex_aov <- function(x,
       # All variables in the non-linear formulas get dumped in the "non-linear"
       # vector of the list. This may include cluster variables which identify
       # random effects components.
-      l_pforms <- unname(unlist(lapply(nf$pforms, all.vars), recursive = TRUE))
+      l_pforms <- unlist(lapply(nf$pforms, all.vars), recursive = TRUE, use.names = FALSE)
       # don't overwrite. maybe this could be smarter
       if (length(l_pforms) > 0 && !"nonlinear" %in% names(l) && !"nonlinear" %in% names(f)) {
         f <- c(f, list(nonlinear = NULL)) # need this for renaming and subsetting later
