@@ -96,7 +96,7 @@ find_statistic <- function(x, ...) {
     "ivreg", "ivFixed", "iv_robust", "ivprobit",
     "lm", "lm_robust", "lm.beta", "lme", "lmerMod", "lmerModLmerTest",
     "lmodel2", "lmRob", "lmrob", "lqm", "lqmm",
-    "maxLik", "mixed", "mhurdle", "mlm", "multinom", "mmrm", "mmrm_fit",
+    "maxLik", "mixed", "mhurdle", "mlm", "mmrm", "mmrm_fit",
     "mmrm_tmb",
     "nlmerMod", "nlrq", "nls",
     "ols", "orcutt",
@@ -126,7 +126,7 @@ find_statistic <- function(x, ...) {
     "lavaan", "loggammacenslmrob", "logitmfx", "logitor", "logitr", "LORgee", "lrm",
     "margins", "marginaleffects", "marginaleffects.summary", "metaplus", "mixor",
     "MixMod", "mjoint", "mle", "mle2", "mlogit", "mblogit", "mclogit", "mmclogit",
-    "mvmeta", "mvord",
+    "multinom", "mvmeta", "mvord",
     "negbin", "negbinmfx", "negbinirr", "nlreg", "nestedLogit",
     "objectiveML", "orm",
     "poissonmfx", "poissonirr", "psm", "probitmfx", "pgmm", "phyloglm",
